

import pong.client.PongClientLayer;
import pong.client.PongClientSession;
import appia.Appia;
import appia.AppiaCursorException;
import appia.AppiaDuplicatedSessionsException;
import appia.AppiaInvalidQoSException;
import appia.Channel;
import appia.ChannelCursor;
import appia.Layer;
import appia.QoS;
import appia.protocols.tcpcomplete.TcpCompleteLayer;

/**
 * @author nuno
 */
public class RunClient {

	public static void main(String[] args) {
		/*
		 * Arguments
		 */
		if(args.length != 2)
			invalidArgs();
		String remoteHost = args[0];
		int remotePort = Integer.parseInt(args[1]);
		
		/*
		 * First thing we have to do is to create an array with the
		 * layers that we want to put on the channel.
		 * Index 0 is the lower layer of the channel.
		 */
		Layer[] qos = {
			//new UdpSimpleLayer(),
			//new FifoLayer(),
			new TcpCompleteLayer(),
			new PongClientLayer()
		}; 
		
		/*
		 * With the array of channels, we create the QoS
		 */
		QoS myQoS = null;
		try {
			myQoS = new QoS("Test pong QoS",qos);
		} catch (AppiaInvalidQoSException e) {
			e.printStackTrace();
		}
		
		/*
		 * The Channel is created from the QoS.
		 * The Channel is NOT running yet and is not initialized.
		 */
		Channel channel = myQoS.createUnboundChannel("pong_c");
		
		/*
		 * If we need to pass parameters to one of the Sessions, we must create it
		 * from the corresponding Layer and initialize it.
		 * In this case, we need to pass remote host and port.
		 */
		PongClientSession session = (PongClientSession) qos[qos.length-1].createSession();
			/*
			 * Arguments are passed here.
			 */
		session.init(remoteHost,remotePort);
		/*
		 * We must use a cursor to instanciate the session in the channel.
		 */
		ChannelCursor cc = channel.getCursor();
		/*
		 * The session is in the top of the channel.
		 */
		cc.top();
		try {
			/*
			 * Session is set here
			 */
			cc.setSession(session);
		} catch (AppiaCursorException e3) {
			e3.printStackTrace();
		}
		/*
		 * Uninitialized Sessions are set here. They are created by Appia.
		 */
		try {
			channel.start();
		} catch (AppiaDuplicatedSessionsException e1) {
			e1.printStackTrace();
		}
		/*
		 * All is set. Every thing is ready to run Appia.
		 */
		Appia.run();
	}

	/**
	 * 
	 */
	private static void invalidArgs() {
		System.out.println("Invalid number of arguments. Usage:");
		System.out.println("java RunClient <server_host> <server_port>");
		System.exit(1);
	}
}
