/*
 * Created on 15-Sep-2003
 *
 */
package pong;

import java.io.Serializable;

/**
 * Class that represents the state of the ball.
 * The state of the pong ball is the current position in the field (a Point) and its
 * velocity vector.
 * The ball is instanciated by the given interface (see {@link pong.client.PongInterface})
 * 
 * @author nuno
 */
public class BallState implements Serializable {
	private static final long serialVersionUID = 3047286294533137460L;
	private int xPosition;
	private int yPosition;
	private int xSpeed;
	private int ySpeed;
	
	/**
	 * Class constructor.
	 * @param x position xx of the ball
	 * @param y position yy of the ball
	 * @param xs xx component of the velocity vector.
	 * @param ys yy component of the velocity vector.
	 */
	public BallState(int x, int y, int xs, int ys){
		xPosition = x;
		yPosition = y;
		xSpeed = xs;
		ySpeed = ys;
	}

	/**
	 * Returns the xx position of the ball.
	 * @return the xx position of the ball.
	 */
	public int getXPosition() {
		return xPosition;
	}

	/**
	 * Updates the xx position of the ball.
	 * @param position new xx position of the ball.
	 */
	public void setXPosition(int position) {
		xPosition = position;
	}

	/**
	 * Returns the xx component of the velocity vector of the ball
	 * @return the xx component of the velocity vector of the ball
	 */
	public int getXSpeed() {
		return xSpeed;
	}

	/**
	 * Updates the xx component of the velocity vector of the ball
	 * @param speed the new value of the xx component of the velocity vector of the ball
	 */
	public void setXSpeed(int speed) {
		xSpeed = speed;
	}

	/**
	 * Returns the yy position of the ball.
	 * @return the yy position of the ball.
	 */
	public int getYPosition() {
		return yPosition;
	}

	/**
	 * Updates the yy position of the ball
	 * @param position the new value for the yy position of the ball
	 */
	public void setYPosition(int position) {
		yPosition = position;
	}

	/**
	 * Returns the yy component of the velocity vector of the ball
	 * @return the yy component of the velocity vector of the ball
	 */
	public int getYSpeed() {
		return ySpeed;
	}

	/**
	 * Updates the yy component of the velocity vector of the ball
	 * @param speed the new value for the yy component of the velocity vector of the ball
	 */
	public void setYSpeed(int speed) {
		ySpeed = speed;
	}

	/**
	 * Increments the position of the ball. Move the ball one step forward. 
	 */
	public void incPosition(){
		xPosition += xSpeed;
		yPosition += ySpeed;
	}

}

