package pong.client;

import java.awt.Graphics;
import java.awt.Point;

import pong.BallState;

/**
 * Class that represents the ball of the game.
 * This class is created automatically by the API provided (see @link pong.client.PongInterface}).
 * 
 * @author  nuno
 */
public class Ball {

	private BallState ballState;
	final int radius = 10;
	private Paddle[] paddles;

	/**
	 * Class constructor.
	 * @param initialPos initial position of the ball.
	 * @param paddles the array of paddles.
	 */
	public Ball(Point initialPos, Paddle[] paddles) {
		init(paddles);
		ballState = new BallState(initialPos.x,initialPos.y,8,6);
	}

	private void init(Paddle[] paddles){
		this.paddles = paddles;
	}

	/**
	 * Move the ball to the given position and repaint it on the given component. 
	 * @param newState the new state of the ball.
	 * @param g graphics of the component where the ball should be painted.
	 */
	public void move(BallState newState, Graphics g){
		clear(g);
		ballState = newState;
		paint(g);
	}

	/**
	 * Returns the state of the ball.
	 * @return the state of the ball.
	 */
	protected BallState getBallState() {
		return ballState;
	}

	/**
	 * Updates the state of the ball
	 * @param ballState the new state of the ball.
	 */
	protected void setBallState(BallState ballState) {
		this.ballState = ballState;
	}
	
	private void clear(Graphics g) {
		g.clearRect(ballState.getXPosition() - radius, ballState.getYPosition() - radius, 2 * radius, 2 * radius);
	}

	/**
	 * Paints the ball on the given Graphics.
	 * @param g the graphics where to paint the ball. 
	 */
	public void paint(Graphics g) {
		g.fillOval(ballState.getXPosition() - radius, ballState.getYPosition() - radius, 2 * radius, 2 * radius);
		for(int i=0; i<paddles.length; i++)
			paddles[i].paint(g);
	}

}
