/*
 * Created on 16-Sep-2003
 */
package pong.client;

import java.awt.Canvas;
import java.awt.Graphics;
import java.awt.Image;


/**
 * Canvas used as field of the game.
 * @author nuno
 */
public class PongCanvas extends Canvas {

	private static final long serialVersionUID = 5877198399395645936L;
	private Ball ball;
	private Paddle[] paddles;
	Image offScreenBuffer;


	/**
	 * Class constructor.
	 * @param ball ball of the game.
	 * @param paddles array with the paddles of the game.
	 */
	public PongCanvas(Ball ball, Paddle[] paddles) {
		super();
		this.ball = ball;
		this.paddles = paddles;
		// this.createBufferStrategy(2);
	}

	/**
	 * Redefinition of the paint method of the canvas.
	 * @see java.awt.Component#paint(java.awt.Graphics)
	 */
	public void paint(Graphics g){
		// super.paint(g);
		if(ball != null)
			ball.paint(g);
		if(paddles != null)
			for (int i=0; i< paddles.length; i++)
				paddles[i].paint(g); 
	}

	/**
	 * Update the graphics.
	 * @param g the graphics to be updated.
	 */
	public void update(Graphics g){
		Graphics gr; 
		// Will hold the graphics context from the offScreenBuffer.
		// We need to make sure we keep our offscreen buffer the same size
		// as the graphics context we're working with.
		if (offScreenBuffer==null ||
			(! (offScreenBuffer.getWidth(this) == this.getWidth()
                && offScreenBuffer.getHeight(this) == this.getHeight()))){
			offScreenBuffer = this.createImage(this.getWidth(), this.getHeight());
        }

		// We need to use our buffer Image as a Graphics object:
		gr = offScreenBuffer.getGraphics();
		// Passes our off-screen buffer to our paint method, which,
		// unsuspecting, paints on it just as it would on the Graphics
		// passed by the browser or applet viewer.
		paint(gr); 
		// And now we transfer the info in the buffer onto the
		// graphics context we got from the browser in one smooth motion.
		g.drawImage(offScreenBuffer, 0, 0, this);
    }

	/**
	 * Updates the ball of the game.
	 * @param b the ball update.
	 */
	public void setBall(Ball b){
		ball = b;
	}

	/**
	 * Updates the paddles of the game.
	 * @param p the new array of paddles.
	 */
	public void setPaddles(Paddle[] p){
		paddles = p;
	}
}
