package pong.client;

import java.awt.Graphics;
import java.awt.Point;

import pong.BallState;
import appia.Channel;

/**
 * Class that creates the interface to be used by the Session.
 * Is this API that will be used to do the project.
 * @author nuno
 */
public class PongInterface {

	private PongGraphics pong;
	private Graphics graphics;
	
	/**
	 * Class constructor. This creates the paddles and tha ball.
	 * @param appiaChannel the appia channel to be used by this application.
	 * @param myPaddle the id of the paddle.
	 */
	public PongInterface(Channel appiaChannel, int myPaddle){
		pong = new PongGraphics(appiaChannel, myPaddle);
		graphics = pong.getCanvas().getGraphics();
	}

	/**
	 * Builds a ball in a given position.
	 * @param initialPos initial position of the ball.
	 */
	public void createBall(Point initialPos){
		pong.createBall(initialPos);
	}

	/**
	 * Moves the ball to the given position. The ball state is updated and the ball is
	 * repainted on the canvas.
	 * @param newState the updated state of the ball (position and velocity vector).
	 */
	public void moveBall(BallState newState){
			pong.getBall().move(newState, graphics);
	}

	/**
	 * Moves the paddle to the given position. The paddle position is updated and the paddle is
	 * repainted on the canvas.
	 * @param player the player id.
	 * @param point the new position of the paddle.
	 */
	public void movePaddle(int player, Point point){
		pong.getPaddle(player).move(point, graphics);
	}

	/**
	 * Activates/Deactivates the paddle of the given player id.
	 * @param player the player id.
	 * @param active true to activate the paddle, false otherwise.
	 */
	public void activePaddle(int player, boolean active){
		pong.getPaddle(player).setActive(active);
	}

	/**
	 * Changes the window title, adding the player id.
	 * @param player the id of the player.
	 */
	public void setWindowTitle(int player){
		pong.setWindowTitle(player);
	}

	/**
	 * Updates the pontuation of the given player.
	 * @param player the player id that suffered the goal.
	 * @param newPont new pontuation of the player.
	 */
	public void updatePontuation(int player, int newPont){
		pong.updatePontuation(player, newPont);
	}	
	
	/**
	 * Returns the pontuation of a given player.
	 * @param player player id
	 * @return the pontuation of a given player.
	 */
	public int getPontuation(int player){
		return pong.getPontuation(player);
	}
	
	/**
	 * Returns the state of the ball.
	 * @return the state of the ball.
	 */
	public BallState getBallState(){
		if(pong.getBall() == null)
			return null;
		return pong.getBall().getBallState();
	}
}
