package pong.events;

import appia.AppiaEventException;
import appia.Channel;
import appia.Session;
import appia.events.SendableEvent;
import appia.message.ExtendedMessage;

/**
 * All events produced by the client descend from this class.
 * 
 * @author jmocito
 */
public class ClientEvent extends SendableEvent {

	/**
	 * Constructs a ClientEvent object.
	 */
	public ClientEvent() {
		super(new ExtendedMessage());
	}

	/**
	 * Constructs a ClientEvent object.
	 * 
	 * @param channel the Channel where this event will be sent.
	 * @param dir the direction of the event.
	 * @param source the Session that produced this event.
	 * 
	 * @throws AppiaEventException
	 */
	public ClientEvent(Channel channel, int dir, Session source)
			throws AppiaEventException {
		super(channel, dir, source,new ExtendedMessage());
	}

	/**
	 * Constructs a ClientEvent object.
	 * 
	 * @param msg the ExtendedMessage to be stored by this event.
	 */
	public ClientEvent(ExtendedMessage msg) {
		super(msg);
	}

	/**
	 * Constructs a ClientEvent object.
	 * 
	 * @param channel the Channel where this event will be sent.
	 * @param dir the direction of the event.
	 * @param source the Session that produced this event.
	 * @param msg the ExtendedMessage to be stored by this event.
	 * @throws AppiaEventException
	 */
	public ClientEvent(Channel channel, int dir, Session source, ExtendedMessage msg)
			throws AppiaEventException {
		super(channel, dir, source, msg);
	}
	
	/**
	 * Returns the ExtendedMessage stored in this event.
	 * 
	 * @return the ExtendedMessage stored in this event.
	 */
	public ExtendedMessage getExtendedMessage() {
		return (ExtendedMessage) super.getMessage();
	}
}
