package pong.events;

import appia.AppiaEventException;
import appia.AppiaException;
import appia.Channel;
import appia.Direction;
import appia.Session;
import appia.events.channel.PeriodicTimer;

/**
 * Appia timer that, once initialized, will be periodically issued by Appia, flowing up in
 * the stack, and being delivered to all the layers that accept this timer.
 * 
 * This timer only needs to be initialized only once, with the qualifier set to
 * {@link EventQualifier.ON}. After that Appia will periodically issue the timer until it is
 * explicitly stopped by some session. To stop a timer one needs to send another timer event
 * with the same name as the timer to be stopped but with the qualifier set to
 * {@link EventQualifier.OFF}. 
 * 
 * @author ncarvalho & jmocito
 */
public class MoveBallTimer extends PeriodicTimer {

	/**
	 * Constructs a MoveBallTimer object.
	 */
	public MoveBallTimer() {
		super();
	}

	/**
	 * Constructs a MoveBallTimer object.
	 * 
	 * @param period the period of the event (in milliseconds)
	 * @param channel the Appia channel where the timer will be sent.
	 * @param source the Session that issues this timer.
	 * @param qualifier the qualifier of the timer (accepts values {@link EventQualifier.ON}
	 * 	and {@link EventQualifier.OFF}.
	 * @throws AppiaEventException
	 * @throws AppiaException
	 */
	public MoveBallTimer(
		long period,
		Channel channel,
		Session source,
		int qualifier)
		throws AppiaEventException, AppiaException {
		super("Pong Timer", period, channel, Direction.DOWN, source, qualifier);
	}
}
