package pong.events;

import java.awt.Point;

/**
 * Event generated by the interface of the game when a player moves is mouse or presses
 * the corresponding cursor keys, signaling the intention to move the corresponding
 * paddle.
 * 
 * @author ncarvalho & jmocito
 */
public class MovePaddleEvent extends ClientEvent {

	/**
	 * The position of the mouse or cursor.
	 */
	private Point point;

	/**
	 * Constructs a MovePaddleEvent object.
	 */
	public MovePaddleEvent(){
		super();
	}

	/**
	 * Sets the position of the paddle.
	 * 
	 * If this position is to be sent through the network than it should
	 * be placed in the message of this event.
	 * 
	 * @param point the position of the mouse or cursor key.
	 */
	public void setPoint(Point point) {
		this.point = point;
	}

	/**
	 * Returns the position stored in this event.
	 * 
	 * @return the position stored in this event.
	 */
	public Point getPoint() {
		return point;
	}
}
