package pong.server;

/**
 * Exception used to signal when the ball hits the wall.
 * 
 * @author nuno
 */
public class OutOfFieldException extends Exception {

	private static final long serialVersionUID = 1L;
	
	// Identifier of the wall where the ball hit
	private int wall;

	/**
	 * Constructs an OutOfFieldException.
	 */
	public OutOfFieldException() {
		super();
		wall = -1;
	}

	/**
	 * Constructs an OutOfFieldException with the given message and
	 * wall identifier.
	 * 
	 * @param message the message associated with the exception.
	 * @param wall the identifier of the wall where the ball hit.
	 */
	public OutOfFieldException(String message, int wall) {
		super(message);
		this.wall = wall;
	}

	/**
	 * Returns the identifier of the wall where the ball hit.
	 * 
	 * @return the identifier of the wall where the ball hit.
	 */
	public int getWall() {
		return wall;
	}
	
	/**
	 * Sets the wall where the ball hit.
	 * 
	 * @param wall the wall where the ball hit.
	 */
	public void setWall(int wall) {
		this.wall = wall;
	}
}