package pong.server;

import pong.events.MoveBallTimer;
import pong.events.MovePaddleEvent;
import pong.events.PlayerInfo;
import pong.events.RegisterFailedEvent;
import pong.events.RegisterPlayerEvent;
import pong.events.StartEvent;
import pong.events.StateEvent;
import appia.Layer;
import appia.Session;
import appia.events.channel.ChannelInit;
import appia.protocols.common.RegisterSocketEvent;
import appia.protocols.tcpcomplete.TcpUndeliveredEvent;

/**
 * The layer associated with the Pong server session. This layer is used to create
 * instances of PongServerSession and states the provided, required and accepted
 * events for that session.
 * 
 * @author jmocito
 */
public class PongServerLayer extends Layer {

	public PongServerLayer() {
		super();
		
		// The provided events.
		evProvide=new Class[] {
			RegisterSocketEvent.class,
			PlayerInfo.class,
			StateEvent.class,
			RegisterFailedEvent.class,
			MoveBallTimer.class,
		};
		
		// The required events.
		evRequire=new Class[] {
			ChannelInit.class,
			RegisterSocketEvent.class,
		};
		
		// The accepted events.
		evAccept=new Class[] {
			ChannelInit.class,
			RegisterSocketEvent.class,
			RegisterPlayerEvent.class,
			StartEvent.class,
			MovePaddleEvent.class,
			MoveBallTimer.class,
			TcpUndeliveredEvent.class,
		};
	}

	/**
	 * Creates a new PongServerSession associated with this layer.
	 */
	public Session createSession() {
		return new PongServerSession(this);
	}

}
